
import { Controller, useForm } from "react-hook-form";
import { Box, Button, Typography, Modal, IconButton, InputAdornment } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { Visibility, VisibilityOff } from "@mui/icons-material";
import { useDispatch } from "react-redux";
import { addManager } from "../../redux/slices/managerSlice"; 
import {
	CustomIconButton,
	CustomTextField,
} from "../AddUserModel/styled.css.tsx";
import React from "react";

type Props = {
	open: boolean;
	handleClose: () => void;
};

export default function AddManagerModal({ open, handleClose }: Props) {
	const dispatch = useDispatch();
	const {
		control,
		register,
		handleSubmit,
		formState: { errors },
		reset,
	} = useForm();
	const [showPassword, setShowPassword] = React.useState(false); 

	const onSubmit = async (data: any) => {
		const managerData = {
			name: data.name,
			email: data.email,
			phone: data.phone,
			registeredAddress: data.registeredAddress,
			roleId: data.role, 
			password: data.password, 
			roleName: "Manager", // Add a role name (you can replace this with a dynamic value if needed)
		};

		try {
			// Dispatch the addManager action
			await dispatch(addManager(managerData)).unwrap();
			handleClose(); // Close modal after successful addition
			reset(); // Reset form fields
		} catch (error) {
			console.error("Error adding manager:", error);
		}
	};

	// Toggle password visibility
	const togglePasswordVisibility = () => {
		setShowPassword((prev) => !prev);
	};

	return (
		<Modal
			open={open}
			onClose={handleClose}
			aria-labelledby="add-manager-modal"
		>
			<Box
				sx={{
					position: "absolute",
					top: "50%",
					left: "50%",
					transform: "translate(-50%, -50%)",
					width: 400,
					bgcolor: "background.paper",
					boxShadow: 24,
					p: 3,
					borderRadius: 2,
				}}
			>
				{/* Header */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
					}}
				>
					<Typography variant="h6" fontWeight={600}>
						Add Manager
					</Typography>
					<CustomIconButton onClick={handleClose}>
						<CloseIcon />
					</CustomIconButton>
				</Box>

				{/* Horizontal Line */}
				<Box sx={{ borderBottom: "1px solid #ddd", my: 2 }} />

				{/* Form */}
				<form onSubmit={handleSubmit(onSubmit)}>
					{/* First Row - Manager Name */}
					<Box sx={{ display: "flex", gap: 2 }}>
						{/* Manager Name */}
						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "100%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Manager Name
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter Manager Name"
								size="small"
								error={!!errors.name}
								helperText={
									errors.name ? errors.name.message : ""
								}
								{...register("name", {
									required: "Manager Name is required",
									minLength: {
										value: 2,
										message:
											"Manager Name must be at least 2 characters long",
									},
								})}
							/>
						</Box>
					</Box>

					{/* Second Row - Email, Password */}
					<Box sx={{ display: "flex", gap: 2 }}>
						{/* Email */}
						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "50%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Email
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter Manager Email"
								size="small"
								error={!!errors.email}
								helperText={
									errors.email ? errors.email.message : ""
								}
								{...register("email", {
									required: "Email is required",
									pattern: {
										value: /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/,
										message: "Invalid email address",
									},
								})}
							/>
						</Box>

						{/* Password */}
						<Box sx={{ display: "flex", gap: 2 }}>
							<Box
								sx={{
									display: "flex",
									flexDirection: "column",
									width: "100%",
								}}
							>
								<Typography variant="body2" fontWeight={500}>
									Password
								</Typography>
								<Controller
									name="password"
									control={control}
									rules={{
										required: "Password is required",
										minLength: {
											value: 6,
											message:
												"Password must be at least 6 characters long.",
										},
										pattern: {
											value: /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[@$!%*?&])[A-Za-z\d@$!%*?&]{6,}$/,
											message:
												"Password must contain at least one uppercase letter, one lowercase letter, one number, and one special character.",
										},
									}}
									render={({ field }) => (
										<CustomTextField
											{...field}
											required
											placeholder="Enter Password"
											type={
												showPassword
													? "text"
													: "password"
											}
											id="password"
											fullWidth
											color={
												errors.password
													? "error"
													: "primary"
											}
											size="small"
											InputProps={{
												endAdornment: (
													<InputAdornment position="end">
														<CustomIconButton
															aria-label="toggle password visibility"
															onClick={
																togglePasswordVisibility
															}
															edge="end"
														>
															{showPassword ? (
																<VisibilityOff />
															) : (
																<Visibility />
															)}
														</CustomIconButton>
													</InputAdornment>
												),
											}}
											error={!!errors.password}
											helperText={
												errors.password?.message
											}
										/>
									)}
								/>
							</Box>
							</Box>
					</Box>

					{/* Third Row - Phone Number, Registered Address */}
					<Box sx={{ display: "flex", gap: 2 }}>
						{/* Phone Number */}
						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "50%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Phone Number
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter Phone Number"
								size="small"
								error={!!errors.phone}
								helperText={
									errors.phone ? errors.phone.message : ""
								}
								{...register("phone", {
									required: "Phone Number is required",
									pattern: {
										value: /^[0-9]{10}$/,
										message:
											"Phone number must be 10 digits",
									},
								})}
							/>
						</Box>

						{/* Registered Address */}
						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "50%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Registered Address
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter Registered Address"
								size="small"
								error={!!errors.registeredAddress}
								helperText={
									errors.registeredAddress
										? errors.registeredAddress.message
										: ""
								}
								{...register("registeredAddress", {
									required: "Registered Address is required",
								})}
							/>
						</Box>
					</Box>

					{/* Submit Button */}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							type="submit"
							sx={{
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
								width: "117px",
								"&:hover": { backgroundColor: "#439BC1" },
							}}
						>
							Add Manager
						</Button>
					</Box>
				</form>
			</Box>
		</Modal>
	);
}
