import React, { useEffect, useState } from "react";
import {
	Box,
	Button,
	Typography,
	TextField,
	InputAdornment,
	IconButton,
} from "@mui/material";
import SearchIcon from "@mui/icons-material/Search";
import EqualizerIcon from "@mui/icons-material/Tune";
import CustomTable, { Column } from "../../components/CustomTable";
import AddManagerModal from "../../components/AddManagerModal";
import { useDispatch, useSelector } from "react-redux";
import DeleteModal from "../../components/Modals/DeleteModal";
import {
	managerList,
	addManager,
	updateManager,
	deleteManager,
} from "../../redux/slices/managerSlice";
import { RootState, AppDispatch } from "../../redux/store/store";
import { useForm } from "react-hook-form";
import EditManagerModal from "../../components/EditManagerModal";

export default function ManagerList() {
	const [addModalOpen, setAddModalOpen] = useState<boolean>(false);
	const [editModalOpen, setEditModalOpen] = useState<boolean>(false);
	const [editRow, setEditRow] = useState<any>(null);
	const { reset } = useForm();

	const [deleteModal, setDeleteModal] = useState<boolean>(false);
	const [viewModal, setViewModal] = useState<boolean>(false);
	const [rowData, setRowData] = useState<any | null>(null);
	const [searchTerm, setSearchTerm] = useState("");
	const dispatch = useDispatch<AppDispatch>();
	const managers = useSelector(
		(state: RootState) => state.managerReducer.managers
	);

	useEffect(() => {
		dispatch(managerList());
	}, [dispatch]);

	const handleClickOpen = () => {
		setRowData(null); // Reset row data when opening for new admin
		setAddModalOpen(true);
	};

	const handleCloseModal = () => {
		setAddModalOpen(false);
		setEditModalOpen(false);
		setRowData(null);
		reset();
	};

	const handleAddManager = async (data: {
		name: string;
		email: string;
		phone: string;
		registeredAddress: string;
	}) => {
		try {
			await dispatch(addManager(data)); // Dispatch action to add manager
			await dispatch(managerList()); // Fetch the updated list
			handleCloseModal(); // Close the modal
		} catch (error) {
			console.error("Error adding manager", error);
		}
	};

	const handleUpdate = async (
		id: number,
		name: string,
		email: string,
		phone: string,
		registeredAddress: string
	) => {
		try {
			// Creating the managerData object to match the expected payload structure
			const managerData = {
				name,
				email,
				phone,
				registeredAddress,
			};

			// Dispatching the updateManager action with the correct payload structure
			await dispatch(updateManager({ id, managerData }));
			await dispatch(managerList()); // Refresh the manager list after updating
			handleCloseModal(); // Close the modal after updating
		} catch (error) {
			console.error("Update failed", error);
		}
	};


	// Remove 'stationName' from columns
	const categoryColumns: Column[] = [
		{ id: "srno", label: "Sr No" },
		{ id: "name", label: "Name" },
		{ id: "email", label: "Email" },
		{ id: "phone", label: "Phone" },
		{ id: "registeredAddress", label: "Station Location" },

		{ id: "action", label: "Action", align: "center" },
	];

	// Update rows to remove 'stationName'
	const categoryRows = managers?.map(
		(
			manager: {
				id: number;
				name: string;
				email: string;
				phone: string;
				registeredAddress: string;
			},
			index: number
		) => ({
			id: manager?.id,
			srno: index + 1,
			name: manager?.name,
			email: manager?.email,
			phone: manager.phone ?? "NA",
			registeredAddress: manager?.registeredAddress ?? "NA",
		})
	);

	return (
		<>
			<CustomTable
				columns={categoryColumns}
				rows={categoryRows}
				setDeleteModal={setDeleteModal}
				deleteModal={deleteModal}
				setViewModal={setViewModal}
				viewModal={viewModal}
				setRowData={setRowData}
				setModalOpen={() => setEditModalOpen(true)}
				tableType="manager"
				handleClickOpen={handleClickOpen}
			/>
			<AddManagerModal
				open={addModalOpen}
				handleClose={handleCloseModal}
				handleAddManager={handleAddManager}
			/>
			<EditManagerModal
				open={editModalOpen}
				handleClose={handleCloseModal}
				handleUpdate={handleUpdate}
				editRow={rowData}
			/>
		</>
	);
}
